use std::time::Instant;

use std::time::Duration;

use crate::task::Environment;
use crate::{task::Task, time::Periodically};
use crate::events::System;

pub struct IdleTimer {
    timeout_start: Instant,
    timeout_duration: Duration,
    timeout_check: Periodically
}

impl IdleTimer {
    pub fn new() -> Self {
        IdleTimer {
            timeout_start: Instant::now(),
            timeout_duration: Duration::from_secs(60),
            timeout_check: Periodically::new_every_n_seconds(5)
        }
    }
}

impl Task for IdleTimer {
    fn start(&mut self, env: &mut Environment) {
        env.set_property(System::Idle, true);
    }

    fn on_tick(&mut self, env: &mut Environment) {
        if self.timeout_check.tick() {
            let is_idle: bool = env.get_property(System::Idle).unwrap();
            if !is_idle && self.timeout_start.elapsed() >= self.timeout_duration {
                env.set_property(System::Idle, true);
            }
        }
    }
}